@@ -450,7 +450,13 @@ XtPointer  clientData, callData;
                    NULL);
 
      XtTranslateCoords(topLevel, x, y, &xRoot, &yRoot);
+/*
      XtMoveWidget(w, xRoot+(wao->xoffset), yRoot+(wao->yoffset));
+*/
+     XtVaSetValues(w,
+                         XtNx, xRoot+(wao->xoffset),
+                         XtNy, yRoot+(wao->yoffset),
+                         NULL);
 
      DBUG_VOID_RETURN;
      }
@@ -461,7 +467,8 @@ Widget     w;
 XtPointer  clientData, callData;
      {
      Window root, child;
-     int  x, y, dummy, width, height, wx, wy, screenWidth, screenHeight;
+     int  x, y, win_x,win_y,width,height, screenWidth, screenHeight;
+     Position xRoot,yRoot,wx,wy;
      unsigned int mask;
      int  offset = (int)clientData;
 
@@ -469,16 +476,13 @@ XtPointer  clientData, callData;
 
      (void) XQueryPointer(XtDisplay(w), XtWindow(topLevel),
                          &root, &child,
-                         &x, &y, &dummy, &dummy,
+                         &x, &y, &win_x, &win_y,
                          &mask);
 
-     XtVaGetValues(w,
-                         XtNwidth, &width,
-                         XtNheight, &height,
-                         XtNx, &wx,
-                         XtNy, &wy,
-                         NULL);
 /*
+     fprintf(stderr, "root=%d/%d, win=%d/%d, parent=%d/%d, wxy=%d/%d\n",
+		x,y,win_x,win_y,xRoot,yRoot,wx,wy);
+
      screenWidth = DisplayWidth(XtDisplay(topLevel), DefaultScreen(XtDisplay(topLevel)));
      screenHeight = DisplayHeight(XtDisplay(topLevel), DefaultScreen(XtDisplay(topLevel)));
 
@@ -487,7 +491,11 @@ XtPointer  clientData, callData;
 		x,y,width,height
 	);
 */
-     XtMoveWidget(w, x-offset, y-offset);
+     XtVaSetValues(w,
+                         XtNx, x-offset,
+                         XtNy, y-offset,
+                         NULL);
+
      DBUG_VOID_RETURN;
      }
 
