@@ -16,7 +16,7 @@
  *
  * Date: Mon, Apr 13 1992
  * Author: Stefan Nusser
- * Version: 0.9
+ * Version: 0.91
  */
 
 /*
@@ -536,19 +536,32 @@ int   sig;
 
 /*****************************************************************************
  *    FUNCTION: iSocketPair
- *            Use socketpair on BSD or ioctl on Sys 5
+ *            Use socketpair on BSD or ioctl on Sys 5 or pipes
  *                                                                          
- *    Arguments: array of two file descriptors                       
+ *    Arguments: array of file descriptors
+ * 
+ *               parentRd childWr childRd parentWr
+ *
  *    Returns:  0 if success, otherwise -1                         
  *                                                                          
  *    Used by:  main
  *****************************************************************************/
-
+#ifdef PIPES
+int
+iSocketPair(fd,onlyOne)
+int      fd[4],onlyOne;
+	{
+		if (pipe(&fd[0])<0) return(-1);
+		if (onlyOne) return(0);
+		if (pipe(&fd[2])<0) return(-1);
+		return(0);
+	}
+#else
 #ifdef STREAMS
 #define SPX_DEVICE "/dev/spx"
 int
-iSocketPair(fd)
-int      fd[2];
+iSocketPair(fd, onlyOne)
+int      fd[4], onlyOne;
 	{
 	struct strfdinsert  ins;
 	queue_t                  *pointer;
@@ -581,21 +594,27 @@ int      fd[2];
 		return(-1);
 		}
 
+	fd[2]=fd[1];
+	fd[3]=fd[0];
 	return(0);
 	}
 
 #else
 
 int
-iSocketPair(fd)
-int      fd[2];
+iSocketPair(fd, onlyOne)
+int      fd[4], onlyOne;
 	{
 	if (socketpair(AF_UNIX, SOCK_STREAM, 0, fd) == -1)
 		return(-1);
 	else
+	        {
+	        fd[2]=fd[1];
+	        fd[3]=fd[0];
 		return(0);
+	        } 
 	}
-
+#endif
 #endif
 
 
@@ -630,9 +649,9 @@ char **env;
      char                  *execString;
      char                 application[50];
 
-     int                    sp[2];  
-     int                    ep[2];  
-     int                    cp[2];
+     int                    sp[4];  
+     int                    ep[4];  
+     int                    cp[4];
 
      static XtActionsRec    tclAction[] = {
                             {"exec",  execActionProc},
@@ -839,44 +858,54 @@ char **env;
           *   and stdout channels.
           */
 
-          if (iSocketPair(sp) == -1)
+          if (iSocketPair(sp,0) == -1)
                {
                fprintf(stderr, "Wafe(main): Couldn't create socket, aborting\n");
                exit(-1);
 	       }
+/*
+printf("sp %d %d %d %d\n",sp[0],sp[1],sp[2],sp[3]);
+*/
 
 	 /*
           *   This pair is used to facilitate an additional communication channel.
           */
 
-          if (iSocketPair(cp) == -1)
+          if (iSocketPair(cp,1) == -1)
                {
                fprintf(stderr, "Wafe(main): Couldn't create socket, aborting\n");
                exit(-1);
 	       }
+/*
+printf("cp %d %d %d %d\n",cp[0],cp[1],cp[2],cp[3]);
+*/
 
-          comClient = cp[0];  /* Communication endpoint for client  */
-          comWafe = cp[1];    /* Communication endpoint for wafe    */
-
-
+          comClient = cp[1];  /* Communication endpoint for client  */
+          comWafe = cp[0];    /* Communication endpoint for wafe    */
+/*
+          close(cp[2]);
+          close(cp[3]);
+*/
 	 /*
           *  Used to catch client's error messages - wafe will never write on
           *  this channel!
           */
 
-          if (iSocketPair(ep) == -1)
+          if (iSocketPair(ep,1) == -1)
                {
                fprintf(stderr, "Wafe(main): Couldn't create socket for app's stderr\n");
                exit(-1);
 	       }
-
+/*
+printf("ep %d %d %d %d\n",ep[0],ep[1],ep[2],ep[3]);
+*/
           pid = fork();
     
           if (!pid)                       /* Child-process               */
                {
-               dup2(sp[0], fileno(stdout));
-               dup2(sp[0], fileno(stdin));
-               dup2(ep[0], fileno(stderr));
+               dup2(sp[1], fileno(stdout));
+               dup2(sp[2], fileno(stdin));
+               dup2(ep[1], fileno(stderr));
 
                close(ep[0]);              /* Those 2 are for ..          */
                close(ep[1]);              /* getting stderr-messages.    */
@@ -905,8 +934,10 @@ char **env;
                DBUG_VOID_RETURN;
 	       }
 
-          close(sp[0]);
-          close(ep[0]);
+/*
+          close(sp[1]);
+          close(ep[1]);
+*/
 
           /* Those are the four main communication-channels:
            *
@@ -916,9 +947,9 @@ char **env;
            * 4) wafeCom       additional communication channel
            */
 
-          errorClient = ep[1];
-          toClient = sp[1];
-          fromClient = sp[1];
+          errorClient = ep[0];
+          toClient = sp[3];
+          fromClient = sp[0];
 
           /* If one of the following signals is caught, wafe exits and 
            * the same signal is sent to the application
@@ -955,21 +986,32 @@ char **env;
 
      if (!fileMode)
           {
+/*
+printf("registering inputhandler fromClient %d\n",fromClient);
+*/
           XtAppAddInput(appContext, fromClient, (XtPointer)XtInputReadMask,
                         getInput, (XtPointer)promptMode); 
 
+
           if (!directMode)
 	       { 
+/*
+printf("registering inputhandler errorCLient %d\n",errorClient);
+*/
                XtAppAddInput(appContext, errorClient,
                        (XtPointer)XtInputReadMask, stderrHandlerProc, 
                        (XtPointer)NULL); 
 
+/*
+printf("registering inputhandler comWafe %d\n",comWafe);
+*/
                XtAppAddInput(appContext, comWafe, (XtPointer)XtInputReadMask,
                              communicationHandlerProc, NULL); 
 	       }
 
 	  }
-          
+
+      
      if ((inputMode) && (!execMode))
           XtAppAddInput(appContext, fileno(stdin), (XtPointer)XtInputReadMask,
                         stdinHandlerProc, NULL); 
@@ -1098,10 +1140,3 @@ char **env;
      DBUG_VOID_RETURN;
      }
 
-
-
-
-
-
-
-
